@@ -3,9 +3,9 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20250131';
+our $VERSION = '0.20250228';
 
-# Table last modified: 2025-01-31
+# Table last modified: 2025-02-28
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[0-2]1|55|77|88)|612))',
     '002' => '(?:850[1-4])',
@@ -65,7 +65,7 @@ our %ZIP_TABLE = (
     '059' => '(?:(?:1(?:39[2-6]|59[2-6]|69[23]|292)|0(?:59[2568]|99[3578]|49[236])|2(?:[14]92|598)|8[67]01|3195))',
     '060' => '(?:8(?:5(?:[38]\d|4[1-9]|[12][0-35-9]|6[0135-9]|7[02-9]|0[1-68]|5[0-46-9])|6(?:1\d|5[14-68]|8[6-8]|7[016-8]|0[1-9]|6[16-8]|2[13-57-9]|4[0-46-9]|3[0-24-9])|7(?:11|67|9[5-7]|7[146]|0[35-7]|2[15])|406))',
     '061' => '(?:(?:1(?:39[2-6]|49[236-8]|19[256])|0(?:29[2356]|59[25]|692)|3(?:29[2-6]|197|692)|2292|8501))',
-    '062' => '(?:8(?:6(?:86|1[278]|0[1-357-9]|3[0135]|2[24]|4[12]|6[68])|5(?:01|20|7[025]|1[013467]|5[58]|3[029])))',
+    '062' => '(?:8(?:6(?:86|1[278]|0[1-357-9]|3[0135]|2[24]|4[12]|6[68])|5(?:01|20|7[025]|5[58]|3[029]|1[01467])))',
     '063' => '(?:8(?:5(?:22|0[17]|5[58]|[18][05])|6(?:0[1-36-8]|1[12]|4[15])))',
     '064' => '(?:8(?:5(?:2[1-46]|1[024-689]|6[0-7]|4[0-356]|5[014-8]|8[169]|0[23569]|7[0157]|3[35-7])|6(?:09|2[0-2489]|4[4589]|1[01]|3[039])|798))',
     '065' => '(?:8(?:5(?:[34]3|22|67|78|1[018]|5[058]|0[18])|6(?:0[19]|3[139]|1[0-2])))',
@@ -104,11 +104,11 @@ our %ZIP_TABLE = (
     '098' => '(?:(?:5(?:[78]92|298|595)|(?:28|62|0[13])92|1(?:69[23]|792)|339[23568]))',
     '099' => '(?:(?:2(?:19[2-8]|49[235]|392)|1(?:49[2568]|19[78]|595)|3(?:29[23]|69[78])|4(?:19[256]|492)|(?:56|65)92|049[245]))',
     '100' => '(?:(?:8(?:9(?:4[015]|3[0-37]|8[0-3679]|9[46]|2[0-24679]|1[02-9]|6[0-57-9]|0[1-579]|5[0-35689]|7[013-9])|1(?:7[2468]|1[0137-9]|8[124-9]|2[013-8]|0[1-57-9]|6[05689]|4[0-24]|5[0-24589]|3[0-69])|2(?:28|51|70|0[1357]|8[23578]|3[2-5]|1[4-69]|4[156]|6[0258])|3(?:70|5[015]|3[2358]|2[1245]|0[2367]|4[15]|1[01]|8[038])|5(?:11|4[03]|5[058]|6[07]|8[58]|7[57]|2[0-2]|0[235-7])|6(?:55|2[019]|3[19]|6[356]|7[67]|1[07]|0[126]|4[049])|4(?:5[06]|1[015]|2[47]|3[09]|0[235]|[48][48])|0(?:19|5[015]|7[07-9]|8[068]|6[56])|79[1-4])|6(?:1(?:62|7[0-57]|5[0-2])|2(?:55|77|6[02])|0(?:51|66|80)|75[1-6])|149[28]))',
-    '101' => '(?:8(?:4(?:1[0568]|6[0-246]|7[057]|4[13-68]|3[0379]|8[05]|0[58]|5[0169]|2[1-59])|6(?:8[28]|0[356]|5[146]|6[57]|2[1246-9]|3[01367]|7[026]|4[235-8]|1[01679])|5(?:3[0-245]|6[1258]|7[59]|4[28]|1[25]|0[249]|8[0569]|2[0-578]|5[24589])|3(?:5[013589]|8[38]|4[367]|0[17-9]|3[3568]|1[0138]|2[3-69]|7[258]|6[267])|7(?:0[137]|1[0-25-8])|9(?:41|50|7[37]|8[36])|2(?:28|0[14]|1[0359])|0(?:11|5[04]|0[128])|1(?:01|89)))',
+    '101' => '(?:8(?:6(?:8[28]|0[356]|5[146]|6[57]|2[1246-9]|3[01367]|7[026]|4[235-8]|1[01679])|4(?:1[0568]|6[0-246]|7[057]|4[13-68]|3[0379]|8[05]|0[58]|2[12459]|5[0169])|5(?:3[0-245]|6[1258]|7[59]|4[28]|1[25]|0[249]|8[0569]|2[0-578]|5[24589])|3(?:5[013589]|8[38]|4[367]|0[17-9]|3[3568]|1[0138]|2[3-69]|7[258]|6[267])|7(?:0[137]|1[0-25-8])|9(?:41|50|7[37]|8[36])|2(?:28|0[14]|1[0359])|0(?:11|5[04]|0[128])|1(?:01|89)))',
     '102' => '(?:8(?:1(?:1[0-357-9]|2[02-58]|8[124-8]|0[239]|5[0-25]|3[0-289]|7[0-25-8]|9[0-5]|4[0-24]|6[016])|5(?:0[2-468]|4[013]|5[2-9]|7[01378]|3[0-39]|2[02589]|1[0-3569]|6[013-79]|8[023568])|6(?:3[0-3579]|4[2-5]|2[0-26-8]|8[0589]|7[17-9]|1[0-47-9]|5[0156]|6[06-8]|0[1-4679])|4(?:7[047]|6[0-24-68]|5[0-259]|0[124-7]|4[0158]|2[0146]|8[489]|3[037]|1[01479])|2(?:5[015]|3[0-24-68]|6[045]|8[28]|7[2-57]|2[1-68]|[01][15]|4[016])|3(?:7[0-37]|3[1-36]|2[124]|1[0134]|8[1-38]|6[24]|4[139]|5[0367]|0[1359])|0(?:30|77|8[0-358]|2[256]|5[05]|0[58]|1[125689])|7(?:30|9[58])))',
     '103' => '(?:8(?:2(?:5[0-2569]|3[0-689]|7[036-8]|0[1-68]|8[2457]|1[0-248]|6[0156]|2[124589]|4[013578])|4(?:7[0-3]|0[1-57]|6[0-24-68]|4[38]|3[0-589]|1[0-79]|2[24-7]|8[02457-9]|5[016])|3(?:70|0[1378]|8[0348]|4[15-7]|1[1-478]|5[0-248]|6[036]|3[01357-9]|2[13-58])|5(?:1[0-257]|5[12468]|7[17]|2[0-25]|0[1-356]|6[67]|8[4-68]|3[4-8]|4[238])|6(?:40|5[0136]|3[169]|7[67]|6[068]|8[0469])|0[01]1))',
     '104' => '(?:(?:8(?:1(?:2[2-589]|5[018]|6[12578]|8[389]|7[014-689]|4[2578]|3[0-589]|1[0-24-8]|0[124589])|3(?:1[023579]|7[07-9]|2[458]|8[013689]|6[35]|5[0167]|3[02358]|4[0-5]|0[12467])|4(?:5[06]|3[013589]|1[369]|0[24578]|8[168]|2[0-469]|6[078]|4[02-49])|5(?:33|77|2[136-8]|4[357]|5[014-689]|6[068]|1[078]|8[1458]|0[1256])|2(?:38|40|71|6[26]|5[124578]|0[568]|8[0-59]|1[0-28])|6(?:14|78|5[06]|8[05]|6[15])|0(?:55|77|1[01]|0[1-37]))|6241))',
-    '105' => '(?:(?:8(?:4(?:7[0-257]|8[2-6]|5[1-36-8]|3[13-7]|[46][014-9]|2[0347-9]|1[0-24-9]|0[1-378])|5(?:6[03578]|1[0-2568]|0[1-357-9]|5[013-8]|8[0-57-9]|7[4-9]|2[1-57-9]|3[0457]|4[03-6])|6(?:7[026-8]|3[04]|8[01569]|6[0568]|1[013-5]|2[0135-7]|5[468]|4[0-24]|0[3468])|3(?:1\d|3[01358]|0[1-9]|2[235])|0(?:10|39|55|0[1258]|7[07]|8[58])|7(?:88|0[127]|1[267]))|7(?:0(?:[58]0|77)|36[05-7]|444)|6[09]50))',
+    '105' => '(?:(?:8(?:4(?:7[0-257]|8[2-6]|5[1-36-8]|3[13-7]|0[1-478]|[46][014-9]|2[0347-9]|1[0-24-9])|5(?:6[03578]|1[0-2568]|0[1-357-9]|5[013-8]|8[0-57-9]|7[4-9]|2[1-57-9]|3[0457]|4[03-6])|6(?:7[026-8]|3[04]|8[01569]|6[0568]|1[013-5]|2[0135-7]|5[468]|4[0-24]|0[3468])|3(?:1\d|3[01358]|0[1-9]|2[235])|0(?:10|39|55|0[1258]|7[07]|8[58])|7(?:88|0[127]|1[267]))|7(?:0(?:[58]0|77)|36[05-7]|444)|6[09]50))',
     '106' => '(?:(?:8(?:5(?:6[0-35-79]|0[78]|3[17]|1[458]|7[135-8]|2[12]|5[0-25689]|4[145]|8[0157-9])|6(?:77|4[0-2489]|5[25]|1[16]|6[58]|3[0569]|0[18]|2[0256])|0(?:11|39|0[17])|(?:10|79)7|4(?:01|87))|6(?:1(?:61|88)|06[06])))',
     '107' => '(?:8(?:4(?:20|5[06]|7[127]|0[1-4]|1[126-9]|3[14]|8[24]|4[08]|6[038])|5(?:32|81|0[23578]|7[02]|1[146]|2[0178]|6[037]|5[0268]|4[56])|6(?:01|50|66|1[5-79]|7[46]|3[0-3689]|8[068]|2[0357])|3(?:20|4[0289]|7[013]|8[048]|3[026]|5[125])|0(?:[16]0|77|0[16])))',
     '108' => '(?:(?:8(?:5(?:2[0-35]|3[02369]|0[1-9]|6[0468]|1[0-25]|7[0135]|5[0-35-8]|4[035]|8[0-3568])|3(?:2[25689]|3[134]|1[0356]|7[2359]|8[013-689]|5[058]|6[01]|4[15]|0[13578])|2(?:8[028]|7[056]|4[0-38]|1[0-267]|0[1-36-9]|3[0-4]|5[05]|2[0245])|4(?:56|0[3-57]|2[013-5]|7[078]|1[014-7]|3[29]|6[68]|4[48])|6(?:50|2[28]|1[125-7]|3[1-3689]|0[267]|4[0-28])|0(?:[258]0|71|[01][15])|7(?:07|1[03])|11[78])|63(?:50|63)))',
@@ -217,7 +217,7 @@ our %ZIP_TABLE = (
     '235' => '(?:85(?:58|2[23]|0[15]))',
     '236' => '(?:8(?:5(?:15|40|0[1-4]|5[05])|6(?:09|5[13]|4[158])))',
     '237' => '(?:85(?:23|55|1[05]))',
-    '238' => '(?:(?:8(?:5(?:70|8[058]|3[356]|1[013]|2[02]|6[57]|5[08]|4[01])|6[18]6)|029[28]))',
+    '238' => '(?:(?:8(?:5(?:65|70|8[058]|3[356]|1[013]|2[02]|5[08]|4[01])|6[18]6)|029[28]))',
     '239' => '(?:8(?:5(?:01|28|6[07]|8[58]|5[08])|68[68]))',
     '240' => '(?:(?:8(?:5(?:[02]1|[45]0)|612)|019[235-8]))',
     '241' => '(?:8(?:5(?:25|1[25]|0[12])|606))',
@@ -254,7 +254,7 @@ our %ZIP_TABLE = (
     '275' => '(?:8(?:5(?:02|11|33|[28][058]|6[05]|7[25-7]|5[01])|6(?:[01]1|66)))',
     '276' => '(?:85(?:01|80|2[3-7]))',
     '277' => '(?:8(?:5(?:2[0-25]|1[1589]|0[13-57]|8[124-9]|5[0146-8]|3[139]|7[0-479]|6[1-689])|6(?:86|5[45]|6[16])))',
-    '278' => '(?:8(?:5(?:[02]1|10|33|7[07]|5[05])|6(?:01|86)))',
+    '278' => '(?:8(?:5(?:10|21|33|7[07]|5[05])|6(?:01|86)))',
     '279' => '(?:8(?:5(?:41|67|70|8[0-58]|0[1-6]|5[0358]|2[1-35-79]|1[1269]|3[0-2])|6(?:01|86)))',
     '282' => '(?:86(?:02|10))',
     '283' => '(?:(?:8(?:5(?:11|55|88|0[15])|6(?:50|86)|701)|0195))',
@@ -278,12 +278,12 @@ our %ZIP_TABLE = (
     '302' => '(?:(?:85(?:0[12]|8[56])|0198))',
     '303' => '(?:850[13])',
     '304' => '(?:8[56]01)',
-    '305' => '(?:8(?:5(?:85|0[1-6]|5[05]|7[1-7]|2[01]|1[05-9]|6[013-9])|6(?:34|42|66|8[67]|0[12459])|70[12]))',
+    '305' => '(?:8(?:5(?:30|85|0[1-6]|5[05]|7[1-7]|2[01]|1[05-9]|6[013-9])|6(?:34|42|66|8[67]|0[12459])|70[12]))',
     '306' => '(?:(?:0(?:49[235]|[236]92|595)|86(?:01|86)))',
     '307' => '(?:8[56]01)',
     '308' => '(?:(?:8(?:5(?:[45]0|2[1-4]|1[0-3])|6(?:[03]8|16))|019[34]))',
     '309' => '(?:1(?:29[2-7]|79[237]|19[25]|698))',
-    '310' => '(?:8(?:5(?:[47]0|36|67|0[12589]|8[1568]|5[0158]|2[05]|1[12])|6(?:22|39|41|86|1[06]|7[17]|0[124]|6[68])|282))',
+    '310' => '(?:8(?:5(?:[47]0|36|67|0[12589]|8[1568]|5[0158]|2[05]|1[12])|6(?:22|39|41|86|1[06]|7[17]|0[124]|6[68])|282|717))',
     '311' => '(?:(?:3(?:8(?:80|9[2-4])|19[2-57]|49[2-478])|1(?:39[23]|49[23]|59[23]|792)|4(?:19[3-68]|39[1-3]|59[25])|249[235]|019[23]))',
     '312' => '(?:85(?:0[1-578]|1[01]))',
     '313' => '(?:8(?:6(?:[68]6|11)|511))',
@@ -358,7 +358,7 @@ our %ZIP_TABLE = (
     '382' => '(?:8(?:5(?:33|55|77|0[2358]|8[578]|1[0-2])|633))',
     '383' => '(?:8(?:5(?:55|67|8[158]|[01][15])|6(?:14|86)))',
     '384' => '(?:(?:8(?:5(?:[01]1|58|8[58])|605)|0(?:69[2578]|393|798)|(?:11|22)92))',
-    '385' => '(?:8(?:5(?:[01]1|22|33|8[568]|5[58])|6(?:[01]1|86)))',
+    '385' => '(?:8(?:5(?:[01]1|22|33|8[568]|5[58])|6(?:[01]1|22|86)))',
     '386' => '(?:(?:8(?:5(?:[67]7|22|43|5[135]|8[458]|1[01]|0[15])|6(?:24|0[189]|8[3568]|6[68]|3[48]|1[01])|7(?:05|20|1[05]))|0(?:49[23578]|39[36]|[15]92)|1(?:19[23]|298)|2292))',
     '387' => '(?:8(?:5(?:[26]1|[58]5|0[1-3]|1[12])|60[13]))',
     '388' => '(?:85(?:11|22|55))',
@@ -433,12 +433,12 @@ our %ZIP_TABLE = (
     '459' => '(?:85(?:[01]1|22|40))',
     '460' => '(?:8(?:5(?:5[01589]|2[0-58]|3[0-24-68]|1[0-7]|8[0568]|6[067]|7[578]|0[13-9]|4[15])|6(?:90|7[0-2489]|2[135-8]|0[2568]|6[05-79]|5[01357]|3[0-3578]|1[04-9]|8[1346-9])|4(?:61|7[057]|2[256]|1[125-7]|0[2-58]|8[1-58]|5[0156]|9[01]|4[0457]|3[0-59])|3(?:02|6[06]|2[015]|5[018]|8[38]|3[0138]|1[0-24589])|7(?:20|0[346-8]|1[18])|20[1-4]))',
     '461' => '(?:8(?:5(?:41|60|8[0-2568]|2[025]|3[0-249]|0[13-8]|7[57]|1[12]|5[08])|6(?:66|80|4[015]|5[01458]|1[02]|0[235]|3[0169]|2[016]|7[0-3568])|7(?:0[367]|2[159]|9[58]|1[0457])))',
-    '462' => '(?:8(?:5(?:2[23]|7[5-7]|5[158]|0[189]|3[05]|1[129]|8[08]|4[035])|666|739))',
+    '462' => '(?:8(?:5(?:30|2[23]|7[5-7]|1[12]|[05][18]|8[08]|4[035])|666|739))',
     '463' => '(?:85(?:10|5[057]|2[128]|8[05]|6[0157]|7[157]|0[1-35]|3[03568]|4[013578]))',
     '464' => '(?:8(?:5(?:85|91|4[05-7]|5[058]|2[0-25]|1[12]|6[0167]|3[01369]|7[017])|6(?:[78]1|0[1-3]|4[134]|3[1-357]|6[12]|1[0135-8]|5[0-24])|710))',
     '465' => '(?:8(?:5(?:20|6[05-7]|5[0-258]|0[15-8]|1[0156])|6(?:68|70|1[0-2]|5[01]|2[026])))',
-    '466' => '(?:8(?:5(?:40|6[05-7]|3[39]|2[25]|8[058]|1[0-25]|0[125-7]|5[0458])|6(?:73|88|6[06]|5[05-7]|3[0356])|7(?:11|0[17])))',
-    '467' => '(?:8(?:5(?:01|6[1-367]|7[17]|3[013]|8[0158]|5[58]|2[0-2]|1[01])|6(?:51|86|2[26]|0[1-3]|3[39]|1[01])))',
+    '466' => '(?:8(?:5(?:25|40|6[05-7]|3[39]|8[058]|1[0-25]|0[125-7]|5[0458])|6(?:66|73|88|5[057]|3[036])|7[01]1))',
+    '467' => '(?:8(?:5(?:01|6[1-367]|7[17]|3[013]|8[0158]|5[58]|2[0-2]|1[01])|6(?:51|86|2[26]|0[1-4]|3[39]|1[01])))',
     '468' => '(?:8(?:5(?:51|2[02]|0[1-357]|1[0-4]|8[58]|3[1-467])|626))',
     '469' => '(?:879[367])',
     '470' => '(?:(?:0(?:1(?:9[2-8]|8[68])|29[2-57]|39[2-6]|49[2356]|592)|2(?:19[1-35-8]|39[2-58]|29[26-8]|49[23])|1(?:19[2-68]|29[2-6])|3(?:29[56]|495)))',
@@ -449,10 +449,10 @@ our %ZIP_TABLE = (
     '475' => '(?:8(?:5(?:41|60|74|99|5[057]|2[28]|8[58]|1[01]|0[125])|6(?:[01]1|55|86|6[68])))',
     '476' => '(?:8(?:5(?:[67]7|10|22|33|0[13]|8[58])|6(?:[68]6|01)))',
     '477' => '(?:852[12])',
-    '478' => '(?:8(?:5(?:55|0[1-5])|6(?:01|4[01])))',
+    '478' => '(?:8(?:5(?:55|0[1-35])|6[04]1))',
     '479' => '(?:8(?:5(?:01|55|77|8[5-9]|1[018])|7(?:87|0[1-8]|1[12])|6(?:01|10|23|68)))',
     '480' => '(?:(?:0(?:2(?:8[1278]|9[1-47])|19[23578]|39[235])|1(?:1(?:8[89]|9[2-8])|298)))',
-    '481' => '(?:8(?:5(?:26|88|4[03]|5[058]|1[0135]|0[1-68]|3[1359])|6(?:[08]1|15|78)))',
+    '481' => '(?:8(?:5(?:26|40|88|5[058]|1[0135]|0[1-68]|3[1359])|6(?:[08]1|15)))',
     '482' => '(?:8(?:5(?:01|55|1[01])|6(?:60|86|5[12])))',
     '483' => '(?:8(?:5(?:55|0[257])|7(?:14|0[14])))',
     '484' => '(?:8(?:5(?:0[1-8]|1[0-2])|609))',
@@ -460,13 +460,13 @@ our %ZIP_TABLE = (
     '486' => '(?:8(?:5(?:01|40|67|75|2[23]|1[015]|8[58]|5[05])|6[68]6))',
     '487' => '(?:8(?:6(?:22|50)|501))',
     '488' => '(?:8(?:5(?:[58]5|01|20|78)|6(?:55|66|8[68])))',
-    '489' => '(?:8(?:5(?:20|67|85|5[05]|1[01])|6(?:[58]0|11|4[25])|7(?:01|77)|450))',
+    '489' => '(?:8(?:5(?:20|67|85|5[05]|1[01])|6(?:[58]0|11|4[25])|450|701))',
     '490' => '(?:1(?:29[2-6]|19[2-48]|392))',
     '491' => '(?:(?:8(?:5(?:85|1[2356]|5[1358]|7[15-7]|0[125689]|6[12]|2[68]|3[1-35])|6(?:0[18]|1[0-2]|8[68]))|0(?:39[2-5]|192)))',
     '492' => '(?:8(?:5(?:2[013589]|4[0-25-8]|0[12]|1[023])|6(?:[05]1|46|2[128]|8[0-256])))',
     '494' => '(?:8(?:5(?:1[16]|0[1257])|6(?:[01]1|86)))',
     '495' => '(?:8(?:5(?:31|0[15]|1[017])|601))',
-    '496' => '(?:8(?:5(?:[78]5|3[1-57]|0[138]|5[58])|6(?:01|48|86|3[39])|720))',
+    '496' => '(?:8(?:5(?:75|3[1-57]|0[138]|5[58])|6(?:01|48|86|3[39])|720))',
     '497' => '(?:8(?:5(?:[04][158]|3[138]|2[27]|1[0-2])|60[12]))',
     '498' => '(?:850[1-35])',
     '500' => '(?:8(?:6(?:[14][0568]|5[057]|7[0-26-8]|2[0-25]|0[1-357]|8[0-25-79]|3[05-9]|6[06-8])|5(?:88|6[0-25-7]|0[1-578]|1[0358]|4[0145]|2[1-5]|3[035]|7[017]|5[024-8])|7(?:65|4[0-38]|2[1-357-9]|1[015-8]|3[0-479]|5[0-5]|0[1-378])))',
@@ -522,8 +522,8 @@ our %ZIP_TABLE = (
     '551' => '(?:85[015]1)',
     '552' => '(?:85(?:01|10))',
     '553' => '(?:8(?:5(?:67|1[1-3]|0[13]|5[0358]|8[58])|739))',
-    '554' => '(?:85(?:[01]1|8[58]))',
-    '555' => '(?:85(?:55|0[1-3]))',
+    '554' => '(?:8(?:5(?:[01]1|8[58])|089))',
+    '555' => '(?:8(?:5(?:55|0[1-3])|089))',
     '556' => '(?:8(?:5(?:[38]5|1[056]|0[13]|5[058])|6(?:01|70|6[03-6])))',
     '557' => '(?:8501)',
     '558' => '(?:85(?:01|85|5[58]))',
@@ -906,7 +906,7 @@ our %ZIP_TABLE = (
     '947' => '(?:(?:8(?:5(?:[58]5|40|0[1-46])|7(?:01|65))|019[238]))',
     '948' => '(?:(?:8(?:50[1-4]|602)|0192))',
     '949' => '(?:(?:7(?:49[24-6]|59[24]|277|392)|3(?:29[2-468]|19[2-4]|494)|6(?:69[256]|[124]92|797)|4(?:19[2-4]|39[278])|2(?:19[2-4]|39[24])|5(?:49[2-4]|292)|039[238]|8492))',
-    '950' => '(?:(?:8(?:5(?:6[05-7]|3[0-3579]|0[1-57]|4[013-578]|1[0-48]|5[0-35-9]|7[0-25-79]|8[0-689]|2[02-4])|6(?:7[78]|6[0168]|1[09]|5[0145]|0[1-3568]|[48][01]|2[0-69]|3[039])|7(?:0[17-9]|5[01359]|3[0235-8]|2[0-57]|1[015-8]|9[48]|4[0-24-9])|801)|1(?:1(?:79|9[2-7]|8[1-36-9])|29[2-68]|49[258])|2(?:0(?:8[24-9]|9[235-7])|1(?:8[18]|9[258])|292)|0(?:19[23568]|292)|319[578]))',
+    '950' => '(?:(?:8(?:5(?:6[05-7]|3[0-3579]|0[1-57]|4[013-578]|1[0-48]|5[0-35-9]|7[0-25-79]|8[0-689]|2[02-4])|6(?:7[78]|6[0168]|1[09]|5[0145]|0[1-3568]|[48][01]|2[0-69]|3[039])|7(?:5[01359]|3[0235-8]|2[0-57]|1[015-8]|0[157-9]|9[48]|4[0-24-9])|801)|1(?:1(?:79|9[2-7]|8[1-36-9])|29[2-68]|49[258])|2(?:0(?:8[24-9]|9[235-7])|1(?:8[18]|9[258])|292)|0(?:19[23568]|292)|319[578]))',
     '951' => '(?:8(?:5(?:70|4[04]|2[018]|1[0-489]|6[067]|8[0156]|0[2-478]|3[1356]|5[0-6])|6(?:01|40|78|8[056]|2[0259]|5[05]|3[023]|1[0-2]|6[68])))',
     '952' => '(?:(?:1(?:59[23]|292|393)|850[12]))',
     '953' => '(?:(?:8(?:6(?:66|0[12])|50[13])|019[23]))',
